summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KXMLGUIClient.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KXMLGUIClient.java')
-rw-r--r--kdejava/koala/org/kde/koala/KXMLGUIClient.java40
1 files changed, 20 insertions, 20 deletions
diff --git a/kdejava/koala/org/kde/koala/KXMLGUIClient.java b/kdejava/koala/org/kde/koala/KXMLGUIClient.java
index fd5b809b..20cdd967 100644
--- a/kdejava/koala/org/kde/koala/KXMLGUIClient.java
+++ b/kdejava/koala/org/kde/koala/KXMLGUIClient.java
@@ -2,10 +2,10 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QDomDocument;
+import org.kde.qt.TQDomDocument;
import org.kde.qt.QtSupport;
-import org.kde.qt.QWidget;
-import org.kde.qt.QDomElement;
+import org.kde.qt.TQWidget;
+import org.kde.qt.TQDomElement;
/**
@@ -54,21 +54,21 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
*/
public native KAction action(String name);
/**
- Retrieves an action for a given QDomElement. The default
+ Retrieves an action for a given TQDomElement. The default
implementation uses the "name" attribute to query the action
object via the other action() method.
- @short Retrieves an action for a given QDomElement.
+ @short Retrieves an action for a given TQDomElement.
*/
- public native KAction action(QDomElement element);
+ public native KAction action(TQDomElement element);
/**
Retrieves the entire action collection for the GUI client. If
you subclass KXMLGUIClient you should call
- KActionCollection.setWidget( QWidget ) with this object, or
+ KActionCollection.setWidget( TQWidget ) with this object, or
you will encounter subtle bugs with KAction keyboard shortcuts.
This is not necessary if your KXMLGUIClient is a KMainWindow.
@short Retrieves the entire action collection for the GUI client.
@see KActionCollection#setWidget(
- @see #org#kde#qt#QWidget*
+ @see #org#kde#qt#TQWidget*
*/
public native KActionCollection actionCollection();
/**
@@ -78,13 +78,13 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
*/
public native KInstanceInterface instance();
/**
- @return The parsed XML in a QDomDocument, set by
+ @return The parsed XML in a TQDomDocument, set by
setXMLFile() or setXML().
This document describes the layout of the GUI.
@short
*/
- public native QDomDocument domDocument();
+ public native TQDomDocument domDocument();
/**
This will return the name of the XML file as set by setXMLFile().
If setXML() is used directly, then this will return NULL.
@@ -103,11 +103,11 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
/**
@short
*/
- public native void setXMLGUIBuildDocument(QDomDocument doc);
+ public native void setXMLGUIBuildDocument(TQDomDocument doc);
/**
@short
*/
- public native QDomDocument xmlguiBuildDocument();
+ public native TQDomDocument xmlguiBuildDocument();
/**
This method is called by the KXMLGUIFactory as soon as the client
is added to the KXMLGUIFactory's GUI.
@@ -145,7 +145,7 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
Retrieves a list of all child clients.
@short Retrieves a list of all child clients.
*/
// const QPtrList<KXMLGUIClient>* childClients(); >>>> NOT CONVERTED
/**
A client can have an own KXMLGUIBuilder.
Use this method to assign your builder instance to the client (so that the
@@ -193,7 +193,7 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
This tag will get expanded to a list of actions. In the example
above ( a file manager with a dynamic file menu ), you would call
<pre>
- QPtrList<KAction> file_actions;
+ TQPtrList<KAction> file_actions;
for( ... )
if( ... )
file_actions.append( cool_action );
@@ -209,7 +209,7 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
menu too..
@short ActionLists are a way for XMLGUI to support dynamic lists of actions.
*/
// void plugActionList(const QString& arg1,const QPtrList<KAction>& arg2); >>>> NOT CONVERTED
/**
The complement of plugActionList() ...
@short The complement of plugActionList() .
@@ -217,10 +217,10 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
public native void unplugActionList(String name);
public native void addStateActionEnabled(String state, String action);
public native void addStateActionDisabled(String state, String action);
- // KXMLGUIClient::StateChange getActionsToChangeForState(const QString& arg1); >>>> NOT CONVERTED
- public native void beginXMLPlug(QWidget arg1);
+ // KXMLGUIClient::StateChange getActionsToChangeForState(const TQString& arg1); >>>> NOT CONVERTED
+ public native void beginXMLPlug(TQWidget arg1);
public native void endXMLPlug();
- public native void prepareXMLUnplug(QWidget arg1);
+ public native void prepareXMLUnplug(TQWidget arg1);
public static native String findMostRecentXMLFile(String[] files, StringBuffer doc);
/**
Sets the instance ( KInstance) for this part.
@@ -259,8 +259,8 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
setXMLFile or setXML .
@short Sets the Document for the part, describing the layout of the GUI.
*/
- protected native void setDOMDocument(QDomDocument document, boolean merge);
- protected native void setDOMDocument(QDomDocument document);
+ protected native void setDOMDocument(TQDomDocument document, boolean merge);
+ protected native void setDOMDocument(TQDomDocument document);
/**
This function will attempt to give up some memory after the GUI
is built. It should never be used in apps where the GUI may be
@@ -145,7 +145,7 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
*/
- // const QPtrList<KXMLGUIClient>* childClients(); >>>> NOT CONVERTED
+ // const TQPtrList<KXMLGUIClient>* childClients(); >>>> NOT CONVERTED
/**
A client can have an own KXMLGUIBuilder.
@@ -209,7 +209,7 @@ public class KXMLGUIClient implements QtSupport, KXMLGUIClientInterface {
*/
- // void plugActionList(const QString& arg1,const QPtrList<KAction>& arg2); >>>> NOT CONVERTED
+ // void plugActionList(const TQString& arg1,const TQPtrList<KAction>& arg2); >>>> NOT CONVERTED
/**
The complement of plugActionList() ...